.. _plugins:

======================
    Plugins
======================

Here you will find documentation for plugins shipped with tmt.

.. warning::

    Please, be aware that the documentation below is a work in progress. We are
    working on fixing it, adding missing bits and generally making it better.
    Also, it was originally used for command line help only, therefore the
    formatting is often suboptional.

.. toctree::
    :maxdepth: 2

    Discover <discover>
    Provision <provision>
    Prepare <prepare>
    Execute <execute>
    Finish <finish>
    Report <report>
    Cleanup <cleanup>
    Test Checks <test-checks>
